Struct jwt_compact::alg::Ed25519 [−][src]
pub struct Ed25519;This is supported on crate features
exonum-crypto or ed25519-dalek or ed25519-compact only.Expand description
Integrity algorithm using digital signatures on the Ed25519 elliptic curve.
The name of the algorithm is specified as EdDSA as per IANA registry.
Use with_specific_name() to switch to non-standard Ed25519.
Implementations
Creates an algorithm instance with the algorithm name specified as Ed25519.
This is a non-standard name, but it is used in some apps.