Trait jwt_compact::alg::SigningKey [−][src]
pub trait SigningKey<T>: Sized where
T: Algorithm<SigningKey = Self>, {
fn from_slice(raw: &[u8]) -> Result<Self>;
fn to_verifying_key(&self) -> T::VerifyingKey;
fn as_bytes(&self) -> SecretBytes<'_>;
}Expand description
Signing key for a specific signature cryptosystem. In the case of public-key cryptosystems, this is a private key.
This trait provides a uniform interface for different backends / implementations of the same cryptosystem.
Required methods
Creates a key from raw bytes. Returns an error if the bytes do not represent
a valid key.
fn to_verifying_key(&self) -> T::VerifyingKey
fn to_verifying_key(&self) -> T::VerifyingKey
Converts a signing key to a verification key.
fn as_bytes(&self) -> SecretBytes<'_>
fn as_bytes(&self) -> SecretBytes<'_>
Returns the key as raw bytes.
Implementations should return Cow::Borrowed whenever possible (that is, if the bytes
are actually stored within the implementing data structure).
Implementations on Foreign Types
impl SigningKey<Es256k<CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>>>> for SecretKey
impl SigningKey<Es256k<CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>>>>> for SecretKey
This implementation initializes a libsecp256k1 context once on the first call to
to_verifying_key if it was not initialized previously.