Trait jwt_compact::alg::VerifyingKey[][src]

pub trait VerifyingKey<T>: Sized where
    T: Algorithm<VerifyingKey = Self>, 
{ fn from_slice(raw: &[u8]) -> Result<Self>;
fn as_bytes(&self) -> Cow<'_, [u8]>; }
Verifying key for a specific signature cryptosystem. In the case of public-key cryptosystems, this is a public key.

This trait provides a uniform interface for different backends / implementations of the same cryptosystem.

Required methods

Creates a key from raw bytes. Returns an error if the bytes do not represent a valid key.

Returns the key as raw bytes.

Implementations should return Cow::Borrowed whenever possible (that is, if the bytes are actually stored within the implementing data structure).

Implementations on Foreign Types

Serializes the key as a 33-byte compressed form, as per Self::serialize().

Implementors